@@ -1,4 +1,5 @@
 from networkx.algorithms.assortativity import *
+from networkx.algorithms.asteroidal import *
 from networkx.algorithms.boundary import *
 from networkx.algorithms.bridges import *
 from networkx.algorithms.chains import *
@@ -13,12 +14,13 @@ from networkx.algorithms.core import *
 from networkx.algorithms.covering import *
 from networkx.algorithms.cycles import *
 from networkx.algorithms.cuts import *
+from networkx.algorithms.d_separation import *
 from networkx.algorithms.dag import *
 from networkx.algorithms.distance_measures import *
 from networkx.algorithms.distance_regular import *
 from networkx.algorithms.dominance import *
 from networkx.algorithms.dominating import *
-from networkx.algorithms.efficiency import *
+from networkx.algorithms.efficiency_measures import *
 from networkx.algorithms.euler import *
 from networkx.algorithms.graphical import *
 from networkx.algorithms.hierarchy import *
@@ -30,14 +32,22 @@ from networkx.algorithms.isolate import *
 from networkx.algorithms.matching import *
 from networkx.algorithms.minors import *
 from networkx.algorithms.mis import *
+from networkx.algorithms.moral import *
+from networkx.algorithms.non_randomness import *
 from networkx.algorithms.operators import *
+from networkx.algorithms.planarity import *
+from networkx.algorithms.planar_drawing import *
 from networkx.algorithms.reciprocity import *
+from networkx.algorithms.regular import *
 from networkx.algorithms.richclub import *
 from networkx.algorithms.shortest_paths import *
+from networkx.algorithms.similarity import *
+from networkx.algorithms.graph_hashing import *
 from networkx.algorithms.simple_paths import *
+from networkx.algorithms.smallworld import *
 from networkx.algorithms.smetric import *
 from networkx.algorithms.structuralholes import *
-from networkx.algorithms.triads import *
+from networkx.algorithms.sparsifiers import *
 from networkx.algorithms.swap import *
 from networkx.algorithms.traversal import *
 from networkx.algorithms.triads import *
@@ -49,6 +59,7 @@ from networkx.algorithms.wiener import *
 # the `networkx` namespace.
 import networkx.algorithms.assortativity
 import networkx.algorithms.bipartite
+import networkx.algorithms.node_classification
 import networkx.algorithms.centrality
 import networkx.algorithms.chordal
 import networkx.algorithms.cluster
@@ -77,12 +88,16 @@ from networkx.algorithms.connectivity import all_pairs_node_connectivity
 from networkx.algorithms.connectivity import all_node_cuts
 from networkx.algorithms.connectivity import average_node_connectivity
 from networkx.algorithms.connectivity import edge_connectivity
+from networkx.algorithms.connectivity import edge_disjoint_paths
 from networkx.algorithms.connectivity import k_components
 from networkx.algorithms.connectivity import k_edge_components
 from networkx.algorithms.connectivity import k_edge_subgraphs
+from networkx.algorithms.connectivity import k_edge_augmentation
+from networkx.algorithms.connectivity import is_k_edge_connected
 from networkx.algorithms.connectivity import minimum_edge_cut
 from networkx.algorithms.connectivity import minimum_node_cut
 from networkx.algorithms.connectivity import node_connectivity
+from networkx.algorithms.connectivity import node_disjoint_paths
 from networkx.algorithms.connectivity import stoer_wagner
 from networkx.algorithms.flow import capacity_scaling
 from networkx.algorithms.flow import cost_of_flow
@@ -104,6 +119,7 @@ from networkx.algorithms.tree.branchings import maximum_spanning_arborescence
 from networkx.algorithms.tree.branchings import minimum_branching
 from networkx.algorithms.tree.branchings import minimum_spanning_arborescence
 from networkx.algorithms.tree.coding import *
+from networkx.algorithms.tree.decomposition import *
+from networkx.algorithms.tree.mst import *
 from networkx.algorithms.tree.operations import *
 from networkx.algorithms.tree.recognition import *
-from networkx.algorithms.tree.mst import *
