@@ -1,17 +1,4 @@
-# -*- coding: utf-8 -*-
-#   Copyright (C) 2011-2019 by
-#   Nicholas Mancuso <nick.mancuso@gmail.com>
-#   All rights reserved.
-#   BSD license.
-#   Copyright 2016-2019 NetworkX developers.
-#   NetworkX is distributed under a BSD license
-#
-# Authors:    Nicholas Mancuso (nick.mancuso@gmail.com)
-#             Jeffery Finkelstein <jeffrey.finkelstein@gmail.com>
-#             Dan Schult <dschult@colgate.edu>
 """Functions for computing large cliques."""
-from operator import itemgetter
-
 import networkx as nx
 from networkx.utils import not_implemented_for
 from networkx.algorithms.approximation import ramsey
@@ -106,8 +93,8 @@ def clique_removal(G):
     return maxiset, cliques
 
 
-@not_implemented_for('directed')
-@not_implemented_for('multigraph')
+@not_implemented_for("directed")
+@not_implemented_for("multigraph")
 def large_clique_size(G):
     """Find the size of a large clique in a graph.
 
