@@ -1,19 +1,11 @@
-# -*- coding: utf-8 -*-
-#   Copyright (C) 2013 by
-#   Fred Morstatter <fred.morstatter@asu.edu>
-#   Jordi Torrents <jtorrents@milnou.net>
-#   All rights reserved.
-#   BSD license.
 from networkx.utils import not_implemented_for
 from networkx.utils import py_random_state
 
-__all__ = ['average_clustering']
-__author__ = """\n""".join(['Fred Morstatter <fred.morstatter@asu.edu>',
-                            'Jordi Torrents <jtorrents@milnou.net>'])
+__all__ = ["average_clustering"]
 
 
 @py_random_state(2)
-@not_implemented_for('directed')
+@not_implemented_for("directed")
 def average_clustering(G, trials=1000, seed=None):
     r"""Estimates the average clustering coefficient of G.
 
