@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 import pytest
 
 import networkx as nx
@@ -6,7 +5,6 @@ from networkx.algorithms import bipartite
 
 
 class TestBipartiteBasic:
-
     def test_is_bipartite(self):
         assert bipartite.is_bipartite(nx.path_graph(4))
         assert bipartite.is_bipartite(nx.DiGraph([(1, 0)]))
@@ -73,8 +71,8 @@ class TestBipartiteBasic:
 
     def test_bipartite_degrees(self):
         G = nx.path_graph(5)
-        X = set([1, 3])
-        Y = set([0, 2, 4])
+        X = {1, 3}
+        Y = {0, 2, 4}
         u, d = bipartite.degrees(G, Y)
         assert dict(u) == {1: 2, 3: 2}
         assert dict(d) == {0: 1, 2: 2, 4: 1}
@@ -82,42 +80,42 @@ class TestBipartiteBasic:
     def test_bipartite_weighted_degrees(self):
         G = nx.path_graph(5)
         G.add_edge(0, 1, weight=0.1, other=0.2)
-        X = set([1, 3])
-        Y = set([0, 2, 4])
-        u, d = bipartite.degrees(G, Y, weight='weight')
+        X = {1, 3}
+        Y = {0, 2, 4}
+        u, d = bipartite.degrees(G, Y, weight="weight")
         assert dict(u) == {1: 1.1, 3: 2}
         assert dict(d) == {0: 0.1, 2: 2, 4: 1}
-        u, d = bipartite.degrees(G, Y, weight='other')
+        u, d = bipartite.degrees(G, Y, weight="other")
         assert dict(u) == {1: 1.2, 3: 2}
         assert dict(d) == {0: 0.2, 2: 2, 4: 1}
 
     def test_biadjacency_matrix_weight(self):
-        scipy = pytest.importorskip('scipy')
+        scipy = pytest.importorskip("scipy")
         G = nx.path_graph(5)
         G.add_edge(0, 1, weight=2, other=4)
         X = [1, 3]
         Y = [0, 2, 4]
-        M = bipartite.biadjacency_matrix(G, X, weight='weight')
+        M = bipartite.biadjacency_matrix(G, X, weight="weight")
         assert M[0, 0] == 2
-        M = bipartite.biadjacency_matrix(G, X, weight='other')
+        M = bipartite.biadjacency_matrix(G, X, weight="other")
         assert M[0, 0] == 4
 
     def test_biadjacency_matrix(self):
-        scipy = pytest.importorskip('scipy')
+        scipy = pytest.importorskip("scipy")
         tops = [2, 5, 10]
         bots = [5, 10, 15]
         for i in range(len(tops)):
             G = bipartite.random_graph(tops[i], bots[i], 0.2)
-            top = [n for n, d in G.nodes(data=True) if d['bipartite'] == 0]
+            top = [n for n, d in G.nodes(data=True) if d["bipartite"] == 0]
             M = bipartite.biadjacency_matrix(G, top)
             assert M.shape[0] == tops[i]
             assert M.shape[1] == bots[i]
 
     def test_biadjacency_matrix_order(self):
-        scipy = pytest.importorskip('scipy')
+        scipy = pytest.importorskip("scipy")
         G = nx.path_graph(5)
         G.add_edge(0, 1, weight=2)
         X = [3, 1]
         Y = [4, 2, 0]
-        M = bipartite.biadjacency_matrix(G, X, Y, weight='weight')
+        M = bipartite.biadjacency_matrix(G, X, Y, weight="weight")
         assert M[1, 2] == 2
