@@ -1,30 +1,37 @@
-#    Copyright (C) 2010-2018 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-#
-# Author: Aric Hagberg (hagberg@lanl.gov)
 """Current-flow betweenness centrality measures."""
 import networkx as nx
-from networkx.algorithms.centrality.flow_matrix import *
-from networkx.utils import (not_implemented_for,
-                            reverse_cuthill_mckee_ordering,
-                            py_random_state)
+from networkx.algorithms.centrality.flow_matrix import (
+    CGInverseLaplacian,
+    flow_matrix_row,
+    FullInverseLaplacian,
+    laplacian_sparse_matrix,
+    SuperLUInverseLaplacian,
+)
+from networkx.utils import (
+    not_implemented_for,
+    reverse_cuthill_mckee_ordering,
+    py_random_state,
+)
 
-__all__ = ['current_flow_betweenness_centrality',
-           'approximate_current_flow_betweenness_centrality',
-           'edge_current_flow_betweenness_centrality']
+__all__ = [
+    "current_flow_betweenness_centrality",
+    "approximate_current_flow_betweenness_centrality",
+    "edge_current_flow_betweenness_centrality",
+]
 
 
 @py_random_state(7)
-@not_implemented_for('directed')
-def approximate_current_flow_betweenness_centrality(G, normalized=True,
-                                                    weight=None,
-                                                    dtype=float, solver='full',
-                                                    epsilon=0.5, kmax=10000,
-                                                    seed=None):
+@not_implemented_for("directed")
+def approximate_current_flow_betweenness_centrality(
+    G,
+    normalized=True,
+    weight=None,
+    dtype=float,
+    solver="full",
+    epsilon=0.5,
+    kmax=10000,
+    seed=None,
+):
     r"""Compute the approximate current-flow betweenness centrality for nodes.
 
     Approximates the current-flow betweenness centrality within absolute
@@ -48,7 +55,7 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
       Default data type for internal matrices.
       Set to np.float32 for lower memory consumption.
 
-    solver : string (default='lu')
+    solver : string (default='full')
        Type of linear solver to use for computing the flow matrix.
        Options are "full" (uses most memory), "lu" (recommended), and
        "cg" (uses least memory).
@@ -90,36 +97,34 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
     """
     try:
         import numpy as np
-    except ImportError:
-        raise ImportError('current_flow_betweenness_centrality requires NumPy ',
-                          'http://scipy.org/')
-    try:
-        from scipy import sparse
-        from scipy.sparse import linalg
-    except ImportError:
-        raise ImportError('current_flow_betweenness_centrality requires SciPy ',
-                          'http://scipy.org/')
+    except ImportError as e:
+        raise ImportError(
+            "current_flow_betweenness_centrality requires NumPy " "http://numpy.org/"
+        ) from e
     if not nx.is_connected(G):
         raise nx.NetworkXError("Graph not connected.")
-    solvername = {"full": FullInverseLaplacian,
-                  "lu": SuperLUInverseLaplacian,
-                  "cg": CGInverseLaplacian}
+    solvername = {
+        "full": FullInverseLaplacian,
+        "lu": SuperLUInverseLaplacian,
+        "cg": CGInverseLaplacian,
+    }
     n = G.number_of_nodes()
     ordering = list(reverse_cuthill_mckee_ordering(G))
     # make a copy with integer labels according to rcm ordering
     # this could be done without a copy if we really wanted to
     H = nx.relabel_nodes(G, dict(zip(ordering, range(n))))
-    L = laplacian_sparse_matrix(H, nodelist=range(n), weight=weight,
-                                dtype=dtype, format='csc')
+    L = laplacian_sparse_matrix(
+        H, nodelist=range(n), weight=weight, dtype=dtype, format="csc"
+    )
     C = solvername[solver](L, dtype=dtype)  # initialize solver
     betweenness = dict.fromkeys(H, 0.0)
     nb = (n - 1.0) * (n - 2.0)  # normalization factor
     cstar = n * (n - 1) / nb
     l = 1  # parameter in approximation, adjustable
-    k = l * int(np.ceil((cstar / epsilon)**2 * np.log(n)))
+    k = l * int(np.ceil((cstar / epsilon) ** 2 * np.log(n)))
     if k > kmax:
-        msg = 'Number random pairs k>kmax (%d>%d) ' % (k, kmax)
-        raise nx.NetworkXError(msg, 'Increase kmax or epsilon')
+        msg = f"Number random pairs k>kmax ({k}>{kmax}) "
+        raise nx.NetworkXError(msg, "Increase kmax or epsilon")
     cstar2k = cstar / (2 * k)
     for i in range(k):
         s, t = seed.sample(range(n), 2)
@@ -138,12 +143,13 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
     else:
         factor = nb / 2.0
     # remap to original node names and "unnormalize" if required
-    return dict((ordering[k], float(v * factor)) for k, v in betweenness.items())
+    return {ordering[k]: float(v * factor) for k, v in betweenness.items()}
 
 
-@not_implemented_for('directed')
-def current_flow_betweenness_centrality(G, normalized=True, weight=None,
-                                        dtype=float, solver='full'):
+@not_implemented_for("directed")
+def current_flow_betweenness_centrality(
+    G, normalized=True, weight=None, dtype=float, solver="full"
+):
     r"""Compute current-flow betweenness centrality for nodes.
 
     Current-flow betweenness centrality uses an electrical current
@@ -170,7 +176,7 @@ def current_flow_betweenness_centrality(G, normalized=True, weight=None,
       Default data type for internal matrices.
       Set to np.float32 for lower memory consumption.
 
-    solver : string (default='lu')
+    solver : string (default='full')
        Type of linear solver to use for computing the flow matrix.
        Options are "full" (uses most memory), "lu" (recommended), and
        "cg" (uses least memory).
@@ -212,16 +218,6 @@ def current_flow_betweenness_centrality(G, normalized=True, weight=None,
     .. [2] A measure of betweenness centrality based on random walks,
        M. E. J. Newman, Social Networks 27, 39-54 (2005).
     """
-    try:
-        import numpy as np
-    except ImportError:
-        raise ImportError('current_flow_betweenness_centrality requires NumPy ',
-                          'http://scipy.org/')
-    try:
-        import scipy
-    except ImportError:
-        raise ImportError('current_flow_betweenness_centrality requires SciPy ',
-                          'http://scipy.org/')
     if not nx.is_connected(G):
         raise nx.NetworkXError("Graph not connected.")
     n = G.number_of_nodes()
@@ -230,8 +226,7 @@ def current_flow_betweenness_centrality(G, normalized=True, weight=None,
     # this could be done without a copy if we really wanted to
     H = nx.relabel_nodes(G, dict(zip(ordering, range(n))))
     betweenness = dict.fromkeys(H, 0.0)  # b[v]=0 for v in H
-    for row, (s, t) in flow_matrix_row(H, weight=weight, dtype=dtype,
-                                       solver=solver):
+    for row, (s, t) in flow_matrix_row(H, weight=weight, dtype=dtype, solver=solver):
         pos = dict(zip(row.argsort()[::-1], range(n)))
         for i in range(n):
             betweenness[s] += (i - pos[i]) * row[i]
@@ -242,14 +237,14 @@ def current_flow_betweenness_centrality(G, normalized=True, weight=None,
         nb = 2.0
     for v in H:
         betweenness[v] = float((betweenness[v] - v) * 2.0 / nb)
-    return dict((ordering[k], v) for k, v in betweenness.items())
+    return {ordering[k]: v for k, v in betweenness.items()}
 
 
-@not_implemented_for('directed')
-def edge_current_flow_betweenness_centrality(G, normalized=True,
-                                             weight=None,
-                                             dtype=float, solver='full'):
-    """Compute current-flow betweenness centrality for edges.
+@not_implemented_for("directed")
+def edge_current_flow_betweenness_centrality(
+    G, normalized=True, weight=None, dtype=float, solver="full"
+):
+    r"""Compute current-flow betweenness centrality for edges.
 
     Current-flow betweenness centrality uses an electrical current
     model for information spreading in contrast to betweenness
@@ -275,7 +270,7 @@ def edge_current_flow_betweenness_centrality(G, normalized=True,
       Default data type for internal matrices.
       Set to np.float32 for lower memory consumption.
 
-    solver : string (default='lu')
+    solver : string (default='full')
        Type of linear solver to use for computing the flow matrix.
        Options are "full" (uses most memory), "lu" (recommended), and
        "cg" (uses least memory).
@@ -324,16 +319,7 @@ def edge_current_flow_betweenness_centrality(G, normalized=True,
        M. E. J. Newman, Social Networks 27, 39-54 (2005).
     """
     from networkx.utils import reverse_cuthill_mckee_ordering
-    try:
-        import numpy as np
-    except ImportError:
-        raise ImportError('current_flow_betweenness_centrality requires NumPy ',
-                          'http://scipy.org/')
-    try:
-        import scipy
-    except ImportError:
-        raise ImportError('current_flow_betweenness_centrality requires SciPy ',
-                          'http://scipy.org/')
+
     if not nx.is_connected(G):
         raise nx.NetworkXError("Graph not connected.")
     n = G.number_of_nodes()
@@ -347,22 +333,10 @@ def edge_current_flow_betweenness_centrality(G, normalized=True,
         nb = (n - 1.0) * (n - 2.0)  # normalization factor
     else:
         nb = 2.0
-    for row, (e) in flow_matrix_row(H, weight=weight, dtype=dtype,
-                                    solver=solver):
+    for row, (e) in flow_matrix_row(H, weight=weight, dtype=dtype, solver=solver):
         pos = dict(zip(row.argsort()[::-1], range(1, n + 1)))
         for i in range(n):
             betweenness[e] += (i + 1 - pos[i]) * row[i]
             betweenness[e] += (n - i - pos[i]) * row[i]
         betweenness[e] /= nb
-    return dict(((ordering[s], ordering[t]), float(v))
-                for (s, t), v in betweenness.items())
-
-
-# fixture for nose tests
-def setup_module(module):
-    from nose import SkipTest
-    try:
-        import numpy
-        import scipy
-    except:
-        raise SkipTest("NumPy not available")
+    return {(ordering[s], ordering[t]): float(v) for (s, t), v in betweenness.items()}
