@@ -1,15 +1,8 @@
 """Hubs and authorities analysis of graph structure.
 """
-#    Copyright (C) 2008-2012 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-#    NetworkX:http://networkx.github.io/
 import networkx as nx
-__author__ = """Aric Hagberg (hagberg@lanl.gov)"""
-__all__ = ['hits', 'hits_numpy', 'hits_scipy', 'authority_matrix', 'hub_matrix']
+
+__all__ = ["hits", "hits_numpy", "hits_scipy", "authority_matrix", "hub_matrix"]
 
 
 def hits(G, max_iter=100, tol=1.0e-8, nstart=None, normalized=True):
@@ -51,8 +44,8 @@ def hits(G, max_iter=100, tol=1.0e-8, nstart=None, normalized=True):
 
     Examples
     --------
-    >>> G=nx.path_graph(4)
-    >>> h,a=nx.hits(G)
+    >>> G = nx.path_graph(4)
+    >>> h, a = nx.hits(G)
 
     Notes
     -----
@@ -97,11 +90,11 @@ def hits(G, max_iter=100, tol=1.0e-8, nstart=None, normalized=True):
         # doing a left multiply a^T=hlast^T*G
         for n in h:
             for nbr in G[n]:
-                a[nbr] += hlast[n] * G[n][nbr].get('weight', 1)
+                a[nbr] += hlast[n] * G[n][nbr].get("weight", 1)
         # now multiply h=Ga
         for n in h:
             for nbr in G[n]:
-                h[n] += a[nbr] * G[n][nbr].get('weight', 1)
+                h[n] += a[nbr] * G[n][nbr].get("weight", 1)
         # normalize vector
         s = 1.0 / max(h.values())
         for n in h:
@@ -128,14 +121,14 @@ def hits(G, max_iter=100, tol=1.0e-8, nstart=None, normalized=True):
 
 def authority_matrix(G, nodelist=None):
     """Returns the HITS authority matrix."""
-    M = nx.to_numpy_matrix(G, nodelist=nodelist)
-    return M.T * M
+    M = nx.to_numpy_array(G, nodelist=nodelist)
+    return M.T @ M
 
 
 def hub_matrix(G, nodelist=None):
     """Returns the HITS hub matrix."""
-    M = nx.to_numpy_matrix(G, nodelist=nodelist)
-    return M * M.T
+    M = nx.to_numpy_array(G, nodelist=nodelist)
+    return M @ M.T
 
 
 def hits_numpy(G, normalized=True):
@@ -161,8 +154,8 @@ def hits_numpy(G, normalized=True):
 
     Examples
     --------
-    >>> G=nx.path_graph(4)
-    >>> h,a=nx.hits(G)
+    >>> G = nx.path_graph(4)
+    >>> h, a = nx.hits(G)
 
     Notes
     -----
@@ -185,9 +178,8 @@ def hits_numpy(G, normalized=True):
     """
     try:
         import numpy as np
-    except ImportError:
-        raise ImportError(
-            "hits_numpy() requires NumPy: http://scipy.org/")
+    except ImportError as e:
+        raise ImportError("hits_numpy() requires NumPy: " "http://numpy.org/") from e
     if len(G) == 0:
         return {}, {}
     H = nx.hub_matrix(G, list(G))
@@ -241,8 +233,8 @@ def hits_scipy(G, max_iter=100, tol=1.0e-6, normalized=True):
 
     Examples
     --------
-    >>> G=nx.path_graph(4)
-    >>> h,a=nx.hits(G)
+    >>> G = nx.path_graph(4)
+    >>> h, a = nx.hits(G)
 
     Notes
     -----
@@ -276,17 +268,18 @@ def hits_scipy(G, max_iter=100, tol=1.0e-6, normalized=True):
        http://www.cs.cornell.edu/home/kleinber/auth.pdf.
     """
     try:
-        import scipy.sparse
         import numpy as np
-    except ImportError:
+    except ImportError as e:
         raise ImportError(
-            "hits_scipy() requires SciPy: http://scipy.org/")
+            "hits_scipy() requires SciPy and NumPy:"
+            "http://scipy.org/ http://numpy.org/"
+        ) from e
     if len(G) == 0:
         return {}, {}
     M = nx.to_scipy_sparse_matrix(G, nodelist=list(G))
     (n, m) = M.shape  # should be square
     A = M.T * M  # authority matrix
-    x = scipy.ones((n, 1)) / n  # initial guess
+    x = np.ones((n, 1)) / n  # initial guess
     # power iteration on authority matrix
     i = 0
     while True:
@@ -294,7 +287,7 @@ def hits_scipy(G, max_iter=100, tol=1.0e-6, normalized=True):
         x = A * x
         x = x / x.max()
         # check convergence, l1 norm
-        err = scipy.absolute(x - xlast).sum()
+        err = np.absolute(x - xlast).sum()
         if err < tol:
             break
         if i > max_iter:
@@ -310,10 +303,3 @@ def hits_scipy(G, max_iter=100, tol=1.0e-6, normalized=True):
     hubs = dict(zip(G, map(float, h)))
     authorities = dict(zip(G, map(float, a)))
     return hubs, authorities
-
-
-# fixture for pytest
-def setup_module(module):
-    import pytest
-    numpy = pytest.importorskip('numpy')
-    scipy = pytest.importorskip('scipy')
