@@ -1,11 +1,3 @@
-# test_tournament.py - unit tests for the tournament module
-#
-# Copyright 2015 NetworkX developers.
-#
-# This file is part of NetworkX.
-#
-# NetworkX is distributed under a BSD license; see LICENSE.txt for more
-# information.
 """Unit tests for the :mod:`networkx.algorithms.tournament` module."""
 from itertools import combinations
 
@@ -18,7 +10,7 @@ from networkx.algorithms.tournament import random_tournament
 from networkx.algorithms.tournament import hamiltonian_path
 
 
-class TestIsTournament(object):
+class TestIsTournament:
     """Unit tests for the :func:`networkx.tournament.is_tournament`
     function.
 
@@ -56,11 +48,12 @@ class TestIsTournament(object):
         assert not is_tournament(G)
 
 
-class TestRandomTournament(object):
+class TestRandomTournament:
     """Unit tests for the :func:`networkx.tournament.random_tournament`
     function.
 
     """
+
     def test_graph_is_tournament(self):
         for n in range(10):
             G = random_tournament(5)
@@ -72,7 +65,7 @@ class TestRandomTournament(object):
             assert is_tournament(G)
 
 
-class TestHamiltonianPath(object):
+class TestHamiltonianPath:
     """Unit tests for the :func:`networkx.tournament.hamiltonian_path`
     function.
 
@@ -99,7 +92,7 @@ class TestHamiltonianPath(object):
         assert path[0] in G[path[-1]]
 
 
-class TestReachability(object):
+class TestReachability:
     """Unit tests for the :func:`networkx.tournament.is_reachable`
     function.
 
@@ -122,7 +115,7 @@ class TestReachability(object):
         assert not is_reachable(G, 1, 0)
 
 
-class TestStronglyConnected(object):
+class TestStronglyConnected:
     """Unit tests for the
     :func:`networkx.tournament.is_strongly_connected` function.
 
