@@ -1,24 +1,20 @@
-#    Copyright (C) 2004-2019 by
-#    Aric Hagberg <hagberg@lanl.gov>
-#    Dan Schult <dschult@colgate.edu>
-#    Pieter Swart <swart@lanl.gov>
-#    All rights reserved.
-#    BSD license.
-#
-# Authors: Aric Hagberg (hagberg@lanl.gov),
-#          Pieter Swart (swart@lanl.gov),
-#          Dan Schult(dschult@colgate.edu)
 """
 """
 from collections.abc import Mapping
-import networkx as nx
 
-__all__ = ['AtlasView', 'AdjacencyView', 'MultiAdjacencyView',
-           'UnionAtlas', 'UnionAdjacency',
-           'UnionMultiInner', 'UnionMultiAdjacency',
-           'FilterAtlas', 'FilterAdjacency',
-           'FilterMultiInner', 'FilterMultiAdjacency',
-           ]
+__all__ = [
+    "AtlasView",
+    "AdjacencyView",
+    "MultiAdjacencyView",
+    "UnionAtlas",
+    "UnionAdjacency",
+    "UnionMultiInner",
+    "UnionMultiAdjacency",
+    "FilterAtlas",
+    "FilterAdjacency",
+    "FilterMultiInner",
+    "FilterMultiAdjacency",
+]
 
 
 class AtlasView(Mapping):
@@ -33,13 +29,14 @@ class AtlasView(Mapping):
     AdjacencyView - View into dict-of-dict-of-dict
     MultiAdjacencyView - View into dict-of-dict-of-dict-of-dict
     """
-    __slots__ = ('_atlas',)
+
+    __slots__ = ("_atlas",)
 
     def __getstate__(self):
-        return {'_atlas': self._atlas}
+        return {"_atlas": self._atlas}
 
     def __setstate__(self, state):
-        self._atlas = state['_atlas']
+        self._atlas = state["_atlas"]
 
     def __init__(self, d):
         self._atlas = d
@@ -60,7 +57,7 @@ class AtlasView(Mapping):
         return str(self._atlas)  # {nbr: self[nbr] for nbr in self})
 
     def __repr__(self):
-        return '%s(%r)' % (self.__class__.__name__, self._atlas)
+        return f"{self.__class__.__name__}({self._atlas!r})"
 
 
 class AdjacencyView(AtlasView):
@@ -75,7 +72,8 @@ class AdjacencyView(AtlasView):
     AtlasView - View into dict-of-dict
     MultiAdjacencyView - View into dict-of-dict-of-dict-of-dict
     """
-    __slots__ = ()   # Still uses AtlasView slots names _atlas
+
+    __slots__ = ()  # Still uses AtlasView slots names _atlas
 
     def __getitem__(self, name):
         return AtlasView(self._atlas[name])
@@ -96,7 +94,8 @@ class MultiAdjacencyView(AdjacencyView):
     AtlasView - View into dict-of-dict
     AdjacencyView - View into dict-of-dict-of-dict
     """
-    __slots__ = ()   # Still uses AtlasView slots names _atlas
+
+    __slots__ = ()  # Still uses AtlasView slots names _atlas
 
     def __getitem__(self, name):
         return AdjacencyView(self._atlas[name])
@@ -118,14 +117,15 @@ class UnionAtlas(Mapping):
     UnionAdjacency - View into dict-of-dict-of-dict
     UnionMultiAdjacency - View into dict-of-dict-of-dict-of-dict
     """
-    __slots__ = ('_succ', '_pred')
+
+    __slots__ = ("_succ", "_pred")
 
     def __getstate__(self):
-        return {'_succ': self._succ, '_pred': self._pred}
+        return {"_succ": self._succ, "_pred": self._pred}
 
     def __setstate__(self, state):
-        self._succ = state['_succ']
-        self._pred = state['_pred']
+        self._succ = state["_succ"]
+        self._pred = state["_pred"]
 
     def __init__(self, succ, pred):
         self._succ = succ
@@ -156,7 +156,7 @@ class UnionAtlas(Mapping):
         return str({nbr: self[nbr] for nbr in self})
 
     def __repr__(self):
-        return '%s(%r, %r)' % (self.__class__.__name__, self._succ, self._pred)
+        return f"{self.__class__.__name__}({self._succ!r}, {self._pred!r})"
 
 
 class UnionAdjacency(Mapping):
@@ -176,18 +176,19 @@ class UnionAdjacency(Mapping):
     UnionAtlas - View into dict-of-dict
     UnionMultiAdjacency - View into dict-of-dict-of-dict-of-dict
     """
-    __slots__ = ('_succ', '_pred')
+
+    __slots__ = ("_succ", "_pred")
 
     def __getstate__(self):
-        return {'_succ': self._succ, '_pred': self._pred}
+        return {"_succ": self._succ, "_pred": self._pred}
 
     def __setstate__(self, state):
-        self._succ = state['_succ']
-        self._pred = state['_pred']
+        self._succ = state["_succ"]
+        self._pred = state["_pred"]
 
     def __init__(self, succ, pred):
         # keys must be the same for two input dicts
-        assert(len(set(succ.keys()) ^ set(pred.keys())) == 0)
+        assert len(set(succ.keys()) ^ set(pred.keys())) == 0
         self._succ = succ
         self._pred = pred
 
@@ -207,7 +208,7 @@ class UnionAdjacency(Mapping):
         return str({nbr: self[nbr] for nbr in self})
 
     def __repr__(self):
-        return '%s(%r, %r)' % (self.__class__.__name__, self._succ, self._pred)
+        return f"{self.__class__.__name__}({self._succ!r}, {self._pred!r})"
 
 
 class UnionMultiInner(UnionAtlas):
@@ -224,7 +225,8 @@ class UnionMultiInner(UnionAtlas):
     UnionAdjacency - View into dict-of-dict-of-dict
     UnionMultiAdjacency - View into dict-of-dict-of-dict-of-dict
     """
-    __slots__ = ()   # Still uses UnionAtlas slots names _succ, _pred
+
+    __slots__ = ()  # Still uses UnionAtlas slots names _succ, _pred
 
     def __getitem__(self, node):
         in_succ = node in self._succ
@@ -252,7 +254,8 @@ class UnionMultiAdjacency(UnionAdjacency):
     UnionAtlas - View into dict-of-dict
     UnionMultiInner - View into dict-of-dict-of-dict
     """
-    __slots__ = ()   # Still uses UnionAdjacency slots names _succ, _pred
+
+    __slots__ = ()  # Still uses UnionAdjacency slots names _succ, _pred
 
     def __getitem__(self, node):
         return UnionMultiInner(self._succ[node], self._pred[node])
@@ -278,7 +281,7 @@ class FilterAtlas(Mapping):  # nodedict, nbrdict, keydict
     def __getitem__(self, key):
         if key in self._atlas and self.NODE_OK(key):
             return self._atlas[key]
-        raise KeyError("Key {} not found".format(key))
+        raise KeyError(f"Key {key} not found")
 
     def copy(self):
         try:  # check that NODE_OK has attr 'nodes'
@@ -286,20 +289,17 @@ class FilterAtlas(Mapping):  # nodedict, nbrdict, keydict
         except AttributeError:
             node_ok_shorter = False
         if node_ok_shorter:
-            return {u: self._atlas[u] for u in self.NODE_OK.nodes
-                    if u in self._atlas}
-        return {u: d for u, d in self._atlas.items()
-                if self.NODE_OK(u)}
+            return {u: self._atlas[u] for u in self.NODE_OK.nodes if u in self._atlas}
+        return {u: d for u, d in self._atlas.items() if self.NODE_OK(u)}
 
     def __str__(self):
         return str({nbr: self[nbr] for nbr in self})
 
     def __repr__(self):
-        return '%s(%r, %r)' % (self.__class__.__name__, self._atlas,
-                               self.NODE_OK)
+        return f"{self.__class__.__name__}({self._atlas!r}, {self.NODE_OK!r})"
 
 
-class FilterAdjacency(Mapping):   # edgedict
+class FilterAdjacency(Mapping):  # edgedict
     def __init__(self, d, NODE_OK, EDGE_OK):
         self._atlas = d
         self.NODE_OK = NODE_OK
@@ -319,10 +319,12 @@ class FilterAdjacency(Mapping):   # edgedict
 
     def __getitem__(self, node):
         if node in self._atlas and self.NODE_OK(node):
+
             def new_node_ok(nbr):
                 return self.NODE_OK(nbr) and self.EDGE_OK(node, nbr)
+
             return FilterAtlas(self._atlas[node], new_node_ok)
-        raise KeyError("Key {} not found".format(node))
+        raise KeyError(f"Key {node} not found")
 
     def copy(self):
         try:  # check that NODE_OK has attr 'nodes'
@@ -330,20 +332,28 @@ class FilterAdjacency(Mapping):   # edgedict
         except AttributeError:
             node_ok_shorter = False
         if node_ok_shorter:
-            return {u: {v: d for v, d in self._atlas[u].items()
-                        if self.NODE_OK(v) if self.EDGE_OK(u, v)}
-                    for u in self.NODE_OK.nodes if u in self._atlas}
-        return {u: {v: d for v, d in nbrs.items() if self.NODE_OK(v)
-                    if self.EDGE_OK(u, v)}
-                for u, nbrs in self._atlas.items()
-                if self.NODE_OK(u)}
+            return {
+                u: {
+                    v: d
+                    for v, d in self._atlas[u].items()
+                    if self.NODE_OK(v)
+                    if self.EDGE_OK(u, v)
+                }
+                for u in self.NODE_OK.nodes
+                if u in self._atlas
+            }
+        return {
+            u: {v: d for v, d in nbrs.items() if self.NODE_OK(v) if self.EDGE_OK(u, v)}
+            for u, nbrs in self._atlas.items()
+            if self.NODE_OK(u)
+        }
 
     def __str__(self):
         return str({nbr: self[nbr] for nbr in self})
 
     def __repr__(self):
-        return '%s(%r, %r, %r)' % (self.__class__.__name__, self._atlas,
-                                   self.NODE_OK, self.EDGE_OK)
+        name = self.__class__.__name__
+        return f"{name}({self._atlas!r}, {self.NODE_OK!r}, {self.EDGE_OK!r})"
 
 
 class FilterMultiInner(FilterAdjacency):  # muliedge_seconddict
@@ -367,10 +377,12 @@ class FilterMultiInner(FilterAdjacency):  # muliedge_seconddict
 
     def __getitem__(self, nbr):
         if nbr in self._atlas and self.NODE_OK(nbr):
+
             def new_node_ok(key):
                 return self.EDGE_OK(nbr, key)
+
             return FilterAtlas(self._atlas[nbr], new_node_ok)
-        raise KeyError("Key {} not found".format(nbr))
+        raise KeyError(f"Key {nbr} not found")
 
     def copy(self):
         try:  # check that NODE_OK has attr 'nodes'
@@ -378,20 +390,27 @@ class FilterMultiInner(FilterAdjacency):  # muliedge_seconddict
         except AttributeError:
             node_ok_shorter = False
         if node_ok_shorter:
-            return {v: {k: d for k, d in self._atlas[v].items()
-                        if self.EDGE_OK(v, k)}
-                    for v in self.NODE_OK.nodes if v in self._atlas}
-        return {v: {k: d for k, d in nbrs.items() if self.EDGE_OK(v, k)}
-                for v, nbrs in self._atlas.items() if self.NODE_OK(v)}
+            return {
+                v: {k: d for k, d in self._atlas[v].items() if self.EDGE_OK(v, k)}
+                for v in self.NODE_OK.nodes
+                if v in self._atlas
+            }
+        return {
+            v: {k: d for k, d in nbrs.items() if self.EDGE_OK(v, k)}
+            for v, nbrs in self._atlas.items()
+            if self.NODE_OK(v)
+        }
 
 
 class FilterMultiAdjacency(FilterAdjacency):  # multiedgedict
     def __getitem__(self, node):
         if node in self._atlas and self.NODE_OK(node):
+
             def edge_ok(nbr, key):
                 return self.NODE_OK(nbr) and self.EDGE_OK(node, nbr, key)
+
             return FilterMultiInner(self._atlas[node], self.NODE_OK, edge_ok)
-        raise KeyError("Key {} not found".format(node))
+        raise KeyError(f"Key {node} not found")
 
     def copy(self):
         try:  # check that NODE_OK has attr 'nodes'
@@ -400,11 +419,21 @@ class FilterMultiAdjacency(FilterAdjacency):  # multiedgedict
             node_ok_shorter = False
         if node_ok_shorter:
             my_nodes = self.NODE_OK.nodes
-            return {u: {v: {k: d for k, d in kd.items()
-                            if self.EDGE_OK(u, v, k)}
-                        for v, kd in self._atlas[u].items() if v in my_nodes}
-                    for u in my_nodes if u in self._atlas}
-        return {u: {v: {k: d for k, d in kd.items()
-                        if self.EDGE_OK(u, v, k)}
-                    for v, kd in nbrs.items() if self.NODE_OK(v)}
-                for u, nbrs in self._atlas.items() if self.NODE_OK(u)}
+            return {
+                u: {
+                    v: {k: d for k, d in kd.items() if self.EDGE_OK(u, v, k)}
+                    for v, kd in self._atlas[u].items()
+                    if v in my_nodes
+                }
+                for u in my_nodes
+                if u in self._atlas
+            }
+        return {
+            u: {
+                v: {k: d for k, d in kd.items() if self.EDGE_OK(u, v, k)}
+                for v, kd in nbrs.items()
+                if self.NODE_OK(v)
+            }
+            for u, nbrs in self._atlas.items()
+            if self.NODE_OK(u)
+        }
