@@ -1,7 +1,23 @@
-# -*- encoding: utf-8 -*-
 import pytest
 import networkx as nx
-from networkx.utils import *
+import random
+from networkx.utils import (
+    create_py_random_state,
+    create_random_state,
+    discrete_sequence,
+    dict_to_numpy_array,
+    dict_to_numpy_array1,
+    dict_to_numpy_array2,
+    is_string_like,
+    iterable,
+    groups,
+    make_list_of_ints,
+    make_str,
+    pairwise,
+    powerlaw_sequence,
+    PythonRandomInterface,
+    to_tuple,
+)
 
 
 def test_is_string_like():
@@ -27,7 +43,7 @@ def test_graph_iterable():
 
 
 def test_make_list_of_ints():
-    mylist = [1, 2, 3., 42, -2]
+    mylist = [1, 2, 3.0, 42, -2]
     assert make_list_of_ints(mylist) is mylist
     assert make_list_of_ints(mylist) == mylist
     assert type(make_list_of_ints(mylist)[2]) is int
@@ -42,36 +58,20 @@ def test_random_number_distribution():
 
 
 def test_make_str_with_bytes():
-    import sys
-    PY2 = sys.version_info[0] == 2
-
     x = "qualité"
     y = make_str(x)
-    if PY2:
-        assert isinstance(y, unicode)
-        # Since file encoding is utf-8, the é will be two bytes.
-        assert len(y) == 8
-    else:
-        assert isinstance(y, str)
-        assert len(y) == 7
+    assert isinstance(y, str)
+    assert len(y) == 7
 
 
 def test_make_str_with_unicode():
-    import sys
-    PY2 = sys.version_info[0] == 2
-    if PY2:
-        x = unicode("qualité", encoding='utf-8')
-        y = make_str(x)
-        assert isinstance(y, unicode)
-        assert len(y) == 7
-    else:
-        x = "qualité"
-        y = make_str(x)
-        assert isinstance(y, str)
-        assert len(y) == 7
+    x = "qualité"
+    y = make_str(x)
+    assert isinstance(y, str)
+    assert len(y) == 7
 
 
-class TestNumpyArray(object):
+class TestNumpyArray:
     @classmethod
     def setup_class(cls):
         global numpy
@@ -81,7 +81,7 @@ class TestNumpyArray(object):
 
     def test_numpy_to_list_of_ints(self):
         a = numpy.array([1, 2, 3], dtype=numpy.int64)
-        b = numpy.array([1., 2, 3])
+        b = numpy.array([1.0, 2, 3])
         c = numpy.array([1.1, 2, 3])
         assert type(make_list_of_ints(a)) == list
         assert make_list_of_ints(b) == list(b)
@@ -90,20 +90,19 @@ class TestNumpyArray(object):
         pytest.raises(nx.NetworkXError, make_list_of_ints, c)
 
     def test_dict_to_numpy_array1(self):
-        d = {'a': 1, 'b': 2}
-        a = dict_to_numpy_array1(d, mapping={'a': 0, 'b': 1})
+        d = {"a": 1, "b": 2}
+        a = dict_to_numpy_array1(d, mapping={"a": 0, "b": 1})
         assert_allclose(a, numpy.array([1, 2]))
-        a = dict_to_numpy_array1(d, mapping={'b': 0, 'a': 1})
+        a = dict_to_numpy_array1(d, mapping={"b": 0, "a": 1})
         assert_allclose(a, numpy.array([2, 1]))
 
         a = dict_to_numpy_array1(d)
         assert_allclose(a.sum(), 3)
 
     def test_dict_to_numpy_array2(self):
-        d = {'a': {'a': 1, 'b': 2},
-             'b': {'a': 10, 'b': 20}}
+        d = {"a": {"a": 1, "b": 2}, "b": {"a": 10, "b": 20}}
 
-        mapping = {'a': 1, 'b': 0}
+        mapping = {"a": 1, "b": 0}
         a = dict_to_numpy_array2(d, mapping=mapping)
         assert_allclose(a, numpy.array([[20, 10], [2, 1]]))
 
@@ -111,14 +110,13 @@ class TestNumpyArray(object):
         assert_allclose(a.sum(), 33)
 
     def test_dict_to_numpy_array_a(self):
-        d = {'a': {'a': 1, 'b': 2},
-             'b': {'a': 10, 'b': 20}}
+        d = {"a": {"a": 1, "b": 2}, "b": {"a": 10, "b": 20}}
 
-        mapping = {'a': 0, 'b': 1}
+        mapping = {"a": 0, "b": 1}
         a = dict_to_numpy_array(d, mapping=mapping)
         assert_allclose(a, numpy.array([[1, 2], [10, 20]]))
 
-        mapping = {'a': 1, 'b': 0}
+        mapping = {"a": 1, "b": 0}
         a = dict_to_numpy_array(d, mapping=mapping)
         assert_allclose(a, numpy.array([[20, 10], [2, 1]]))
 
@@ -126,9 +124,9 @@ class TestNumpyArray(object):
         assert_allclose(a.sum(), 33)
 
     def test_dict_to_numpy_array_b(self):
-        d = {'a': 1, 'b': 2}
+        d = {"a": 1, "b": 2}
 
-        mapping = {'a': 0, 'b': 1}
+        mapping = {"a": 0, "b": 1}
         a = dict_to_numpy_array(d, mapping=mapping)
         assert_allclose(a, numpy.array([1, 2]))
 
@@ -150,9 +148,9 @@ def test_pairwise():
 
 
 def test_groups():
-    many_to_one = dict(zip('abcde', [0, 0, 1, 1, 2]))
+    many_to_one = dict(zip("abcde", [0, 0, 1, 1, 2]))
     actual = groups(many_to_one)
-    expected = {0: {'a', 'b'}, 1: {'c', 'd'}, 2: {'e'}}
+    expected = {0: {"a", "b"}, 1: {"c", "d"}, 2: {"e"}}
     assert actual == expected
     assert {} == groups({})
 
@@ -175,16 +173,16 @@ def test_to_tuple():
 
 
 def test_create_random_state():
-    np = pytest.importorskip('numpy')
+    np = pytest.importorskip("numpy")
     rs = np.random.RandomState
 
     assert isinstance(create_random_state(1), rs)
     assert isinstance(create_random_state(None), rs)
     assert isinstance(create_random_state(np.random), rs)
     assert isinstance(create_random_state(rs(1)), rs)
-    pytest.raises(ValueError, create_random_state, 'a')
+    pytest.raises(ValueError, create_random_state, "a")
 
-    assert np.all((rs(1).rand(10) == create_random_state(1).rand(10)))
+    assert np.all(rs(1).rand(10) == create_random_state(1).rand(10))
 
 
 def test_create_py_random_state():
@@ -193,9 +191,9 @@ def test_create_py_random_state():
     assert isinstance(create_py_random_state(1), pyrs)
     assert isinstance(create_py_random_state(None), pyrs)
     assert isinstance(create_py_random_state(pyrs(1)), pyrs)
-    pytest.raises(ValueError, create_py_random_state, 'a')
+    pytest.raises(ValueError, create_py_random_state, "a")
 
-    np = pytest.importorskip('numpy')
+    np = pytest.importorskip("numpy")
 
     rs = np.random.RandomState
     nprs = PythonRandomInterface
@@ -206,7 +204,7 @@ def test_create_py_random_state():
 
 
 def test_PythonRandomInterface():
-    np = pytest.importorskip('numpy')
+    np = pytest.importorskip("numpy")
     rs = np.random.RandomState
     rng = PythonRandomInterface(rs(42))
     rs42 = rs(42)
@@ -215,9 +213,10 @@ def test_PythonRandomInterface():
     assert rng.randrange(3, 5) == rs42.randint(3, 5)
     assert np.all(rng.choice([1, 2, 3]) == rs42.choice([1, 2, 3]))
     assert rng.gauss(0, 1) == rs42.normal(0, 1)
-    assert rng.expovariate(1.5) == rs42.exponential(1/1.5)
+    assert rng.expovariate(1.5) == rs42.exponential(1 / 1.5)
     assert np.all(rng.shuffle([1, 2, 3]) == rs42.shuffle([1, 2, 3]))
-    assert np.all(rng.sample([1, 2, 3], 2) ==
-                       rs42.choice([1, 2, 3], (2,), replace=False))
+    assert np.all(
+        rng.sample([1, 2, 3], 2) == rs42.choice([1, 2, 3], (2,), replace=False)
+    )
     assert rng.randint(3, 5) == rs42.randint(3, 6)
     assert rng.random() == rs42.random_sample()
