@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '2.5.1'
-date = 'Fri May  7 19:44:08 2021'
+version = '2.5'
+date = 'Thu Dec  3 09:37:49 2020'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '2', '5.1', None)
+version_info = ('networkx', '2', '5', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2021, 5, 7, 19, 44, 8)
+date_info = datetime.datetime(2020, 12, 3, 9, 37, 49)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
